# Punt Release

Apply the **`release`** skill. Follow the full procedure in `.cursor/skills/release/SKILL.md`. If the user provided a version as an argument, use it; otherwise it will be auto-detected.
